source_suffix = '.txt'
master_doc = 'index'
project = 'Manuel'
copyright = 'Benji York'
version = '1'
release = '1'
today_fmt = '%Y-%m-%d'
pygments_style = 'sphinx'

html_last_updated_fmt = '%Y-%m-%d'
html_title = 'Manuel Documentation'

todo_include_todos = False
exclude_dirnames = ['manuel.egg-info']
unused_docs = ['manuel/capture']



from __future__ import absolute_import

import doctest
import manuel
import manuel.capture
import manuel.codeblock
import manuel.doctest
import manuel.ignore
import manuel.testcase
import manuel.testing
import os.path
import re
import unittest
import zope.testing.renormalizing

here = os.path.dirname(os.path.abspath(__file__))

checker = zope.testing.renormalizing.RENormalizing([
    (re.compile(r"<unittest\.result\.TestResult"), '<unittest.TestResult'),
    # PyPy spells some error messages differently
    (re.compile(r"NameError: global name '([a-zA-Z0-9_]+)' is not defined"),
     r"NameError: name '\1' is not defined"),
    # PyPy's default __repr__ is slightly different
    (re.compile(r"<__builtin__\.(Table|TableError|NumbersTest|NumbersResult) object"),
     r"<\1 object"),
    # PyPy3's default __repr__ is slightly different
    (re.compile(r"<builtins\.(Table|TableError|NumbersTest|NumbersResult) object"),
     r"<\1 object"),
    (re.compile(r"<SRE_Match object"),
     r"<_sre.SRE_Match object"),
])


def turtle_on_the_bottom_test():
    """We use manuel to test itself.

    This means that if we completely hose manuel, we might not
    know. Use doctest to do a basic sanity check.

    >>> document = manuel.Document('''This is my doctest.
    ...
    ...     >>> 2 + 2
    ...     5
    ... ''')
    >>> document.process_with(manuel.doctest.Manuel(), globs={})
    >>> print(document.formatted())
    File "<memory>", line 3, in <memory>
    Failed example:
        2 + 2
    Expected:
        5
    Got:
        4
    <BLANKLINE>

    """

def test_suite():
    tests = ['index.txt', 'table-example.txt', 'README.txt', 'bugs.txt',
        'capture.txt']

    optionflags = doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS

    m = manuel.ignore.Manuel()
    m += manuel.doctest.Manuel(optionflags=optionflags, checker=checker)
    m += manuel.codeblock.Manuel()
    m += manuel.capture.Manuel()
    m += manuel.testcase.SectionManuel()
    # The apparently redundant "**dict()" is to make this code compatible with
    # Python 2.5 -- it would generate a SyntaxError otherwise.
    suite = manuel.testing.TestSuite(m, *tests, **dict(
        globs={'path_to_test': os.path.join(here, 'bugs.txt')}))


    return unittest.TestSuite((
        suite,
        doctest.DocTestSuite(),
        ))



##############################################################################
#
# Copyright Benji York and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Apache License, Version
# 2.0.
#
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Setup for manuel package."""

from setuptools import setup, find_packages

with open('README.rst') as readme:
    with open('CHANGES.rst') as changes:
        long_description = readme.read() + '\n\n' + changes.read()

tests_require = ['zope.testing']

setup(
    name='manuel',
    version='1.10.1',
    url='http://pypi.python.org/pypi/manuel',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    zip_safe=False,
    author='Benji York',
    author_email='benji@benjiyork.com',
    description='Manuel lets you build tested documentation.',
    classifiers=[
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'License :: OSI Approved :: Apache Software License',
        ],
    license='Apache Software License, Version 2.0',
    extras_require={
        'tests': tests_require,
        },
    tests_require=tests_require,
    test_suite='manuel.tests.test_suite',
    install_requires=[
        'setuptools',
        'six',
        ],
    include_package_data=True,
    long_description=long_description,
    keywords=['testing', 'documentation'],
    )
